# Introduction to visualization in R with ggplot2

# Package documentation at: http://docs.ggplot2.org/current/
# NOTE: there are many ways to get the same result with this package

library(ggplot2)
library(scales)

# 0. Introduction

data(diamonds)

str(diamonds)
summary(diamonds)

plot(diamonds$carat, diamonds$price)
qplot(diamonds$carat, diamonds$price)

theme_set(new=theme_bw())
qplot(diamonds$carat, diamonds$price)

myplot <- qplot(diamonds$price, diamonds$carat)
myplot

ggplot(data=diamonds)

# 1. The geometry "geom" layer and the aesthetic "aes"

ggplot(data=diamonds) + geom_point()
ggplot(data=diamonds) + geom_point(aes(x=carat, y=price))

ggplot(data=diamonds) + geom_point(aes(x=carat, y=price)) + geom_smooth()
ggplot(data=diamonds) + geom_point(aes(x=carat, y=price)) + geom_smooth(aes(x=carat, y=price))
ggplot(data=diamonds) + geom_point(aes(x=carat, y=price)) + geom_smooth(aes(x=carat, y=price), method=lm)


# Working with geom_point() and the aes layer
# Examples: color, fill, shape, size, alpha

ggplot(data=diamonds) + geom_point(aes(x=carat, y=price, color=cut))
ggplot(data=diamonds) + geom_point(aes(x=carat, y=price, color=blue))
ggplot(data=diamonds) + geom_point(aes(x=carat, y=price, color="blue"))
ggplot(data=diamonds) + geom_point(aes(x=carat, y=price), color="blue")

# Most geoms: color is the outline and fill is what we think of as color
# Can use either color or colour in most situations
# Color works for both discrete and continuous variables

ggplot(data=diamonds) + geom_point(aes(x=carat, y=price, color=cut))
ggplot(data=diamonds) + geom_point(aes(x=carat, y=price, color=depth))

ggplot(data=diamonds) + geom_point(aes(x=carat, y=price, color=cut), alpha=1/20)

# Kind of a mess, but we can add a lot of things to a plot
ggplot(data=diamonds) + geom_point(aes(x=carat, y=price, color=cut, shape=color, size=clarity), alpha=1/5)

# 2. The scale layer: add a function from the family scale_
# Tightly connected to the aes
small<-diamonds[sample(nrow(diamonds),1000),]

ggplot(data=small) + geom_point(aes(x=carat, y=price, size=depth))
ggplot(data=small) + geom_point(aes(x=carat, y=price, size=depth)) + scale_size_area()

ggplot(data=small) + geom_point(aes(x=carat, y=price, color=cut)) + scale_color_grey()
ggplot(data=small) + geom_point(aes(x=carat, y=price, color=cut)) + scale_color_brewer()
ggplot(data=small) + geom_point(aes(x=carat, y=price, color=cut)) + scale_color_brewer(palette="Set3")

# You can micromanage your own colors with scale_color_manual()

ggplot(data=small) + geom_point(aes(x=carat, y=price, shape=cut))
ggplot(data=small) + geom_point(aes(x=carat, y=price, shape=cut)) + scale_shape_discrete(solid=FALSE)

ggplot(data=small) + geom_point(aes(x=carat, y=price, color=cut)) + scale_color_brewer(palette="Set3") + scale_x_continuous(name="weight of the diamond (carats)")

# 3. The coordinate layer

ggplot(data=small) + geom_point(aes(x=carat, y=price, color=cut)) + scale_color_brewer(palette="Set3") + coord_trans(x="log10", y="log10")

ggplot(data=small) + geom_point(aes(x=carat, y=price, color=cut)) + scale_color_brewer(palette="Set3") + coord_flip()

ggplot(data=diamonds) + geom_histogram(aes(x=color))
ggplot(data=diamonds) + geom_histogram(aes(x=color)) + coord_polar()

# 4. The position layer

ggplot(data=diamonds) + geom_bar(aes(x=cut, fill=clarity))
ggplot(data=diamonds) + geom_bar(aes(x=cut, fill=clarity), position="dodge")
ggplot(data=diamonds) + geom_bar(aes(x=cut, fill=clarity), position="dodge") + coord_polar()

ggplot(data=diamonds) + geom_point(aes(x=cut, y=price))
ggplot(data=diamonds) + geom_point(aes(x=cut, y=price), position="jitter", alpha=1/10)

# 5. Faceting

ggplot(data=diamonds) + geom_bar(aes(x=cut, fill=clarity)) + facet_wrap(~color)
ggplot(data=diamonds) + geom_bar(aes(x=cut, fill=clarity)) + facet_wrap(~color, nrow=2)
ggplot(data=diamonds) + geom_bar(aes(x=cut, fill=clarity)) + facet_wrap(~color, nrow=2, scales="free")

ggplot(data=diamonds) + geom_bar(aes(x=cut)) + facet_wrap(clarity~color)

ggplot(data=diamonds) + geom_bar(aes(x=cut)) + facet_grid(clarity~color)
ggplot(data=diamonds) + geom_bar(aes(x=cut)) + facet_grid(clarity~color, scales="free")

# 6. Theme and appearance

ggplot(data=diamonds) + geom_bar(aes(x=cut)) + facet_grid(clarity~color, scales="free") + theme(axis.text.x=element_text(angle = -90, hjust=0))

# 7. Wrapping things up

ggsave(file="~/Desktop/diamond-plot.pdf")

# Can specify which plot, which format, where to save it, size
# With a vector graphics plot, everything is a separate object. This may be a problem in a graph with a lot of overplotting.